
.. py:currentmodule:: pythreejs

InstancedBufferAttribute
====================================================

.. Use autoclass to fill any memebers not manually specified.
   This ensures it picks up any members in overridden classes.

.. autohastraits:: InstancedBufferAttribute(array=None, meshPerAttribute=1, )
    :members:
    :undoc-members:


    Inherits :py:class:`~pythreejs.BufferAttribute`.

    Three.js docs: https://threejs.org/docs/#api/core/InstancedBufferAttribute


    .. py:attribute:: meshPerAttribute

        .. sourcecode:: python

            CInt(1, allow_none=False).tag(sync=True)

